@@ -13,7 +13,6 @@ class MeedConfigNotExists(FileNotFoundError):
 class MeedConfig:
     REQUIRED_PROPERTIES = ["Output_File"]
     PROPERTIES = {
-        "AWS_Profile": None,
         "Theme": "DarkGrey",
         "Stats": ["Happiness", "Confidence", "Frustration"],
         "Depth": 10,
@@ -36,9 +35,6 @@ class MeedConfig:
         try:
             self.config = config[profile_name]
         except KeyError:
-            logging.error(
-                f"invalid profile '{profile_name}' for configuration '{self.configuration_file_path}'"
-            )
             raise MeedConfigNotExists
 
     def terminal_list_profiles(self):
