@@ -1,3 +1,4 @@
+import logging
 import typing
 
 from colorama import Fore, Back, Style
@@ -27,6 +28,7 @@ def header(heading: str) -> None:
 
 
 def fatal_error(message: str) -> None:
+    logging.exception(message)
     print(Back.RED + Style.BRIGHT + message + Style.RESET_ALL)
 
 
